# -*- coding: utf-8 -*-
import pandas as pd
import numpy as np
from datetime import datetime
import time
import os

class TimeDistribution():
    def __init__(self, source=None, write_name=None, dis_period='day', time_format='%Y-%m-%d %H:%M:%S'):
        self.distribution(source=source, write_name=write_name, dis_period=dis_period)

    def distribution(self, source=None, write_name=None, dis_period='day', time_format='%Y-%m-%d %H:%M:%S'):
        chunks = pd.read_csv(source, chunksize=100000)
        self.dis_df = pd.DataFrame()
        for df in chunks:
            df['time'] = pd.to_datetime(df['time'], format=time_format)
            if dis_period == 'second':
                df['time'] = df['time'].dt.second
            elif dis_period == 'minute':
                df['time'] = df['time'].dt.minute
            elif dis_period == 'hour':
                df['time'] = df['time'].dt.hour
            elif dis_period == 'dayofweek':
                df['time'] = df['time'].dt.dayofweek
            elif dis_period == 'day':
                df['time'] = df['time'].dt.day
            elif dis_period == 'week':
                df['time'] = df['time'].dt.week
            elif dis_period == 'month':
                df['time'] = df['time'].dt.month
            elif dis_period == 'year':
                df['time'] = df['time'].dt.year
            

            dis_df = df.groupby('time')['time'].count().reset_index(name='count')
            if self.dis_df.shape[0]:
                self.dis_df = pd.merge(left = self.dis_df, right = dis_df, how='outer', on='time')
                self.dis_df = self.dis_df.fillna(0)
                self.dis_df['count'] = self.dis_df['count_x'] + self.dis_df['count_y']
                self.dis_df.drop(['count_x', 'count_y'], axis=1, inplace=True)
            else:
                self.dis_df = dis_df
        self.dis_df['percent'] = self.dis_df['count'] / self.dis_df['count'].sum()
        self.dis_df['percent'] = self.dis_df['percent'].apply(lambda x: format(x, '.2%'))
        print(self.dis_df)
        self.dis_df.to_csv(write_name, encoding='utf_8_sig')




if __name__ == "__main__":
    td = TimeDistribution(dis_period='hour')
